@@ -3,9 +3,18 @@
 # 2.0, and the MIT License.  See the LICENSE file in the root of this
 # repository for complete details.
 
+import os
+
 from importlib import metadata
 
 
+# Set canonical URL from the Read the Docs Domain
+html_baseurl = os.environ.get("READTHEDOCS_CANONICAL_URL", "")
+
+# Tell Jinja2 templates the build is running on Read the Docs
+if os.environ.get("READTHEDOCS", "") == "True":
+    html_context = {"READTHEDOCS": True}
+
 # We want an image in the README and include the README in the docs.
 suppress_warnings = ["image.nonlocal_uri"]
 
@@ -47,7 +56,7 @@ master_doc = "index"
 # General information about the project.
 project = "structlog"
 author = "Hynek Schlawack"
-copyright = f"2013, { author }"
+copyright = f"2013, {author}"
 
 # The version info for the project you're documenting, acts as replacement for
 # |version| and |release|, also used in various other places throughout the
@@ -77,6 +86,7 @@ nitpick_ignore = [
     ("py:class", "WrappedLogger"),
     ("py:class", "structlog.threadlocal.TLLogger"),
     ("py:class", "structlog.typing.EventDict"),
+    ("py:class", "ModuleType"),
 ]
 
 # If true, '()' will be appended to :func: etc. cross-reference text.
@@ -90,9 +100,9 @@ autodoc_typehints_description_target = "documented"
 
 html_theme = "furo"
 html_theme_options = {
-    "top_of_page_button": None,
+    "top_of_page_buttons": [],
     "light_css_variables": {
-        "font-stack": "Inter, sans-serif",
+        "font-stack": "B612, sans-serif",
         "font-stack--monospace": "BerkeleyMono, MonoLisa, ui-monospace, "
         "SFMono-Regular, Menlo, Consolas, Liberation Mono, monospace",
     },
