@@ -21,6 +21,13 @@ import warnings
 from functools import partial
 from typing import Any, Callable, Collection, Dict, Iterable, Sequence, cast
 
+
+if sys.version_info >= (3, 11):
+    from typing import Self
+else:
+    from typing_extensions import Self
+
+
 from . import _config
 from ._base import BoundLoggerBase
 from ._frames import _find_first_app_frame_and_name, _format_stack
@@ -155,13 +162,13 @@ class BoundLogger(BoundLoggerBase):
 
     _logger: logging.Logger
 
-    def bind(self, **new_values: Any) -> BoundLogger:
+    def bind(self, **new_values: Any) -> Self:
         """
         Return a new logger with *new_values* added to the existing ones.
         """
         return super().bind(**new_values)
 
-    def unbind(self, *keys: str) -> BoundLogger:
+    def unbind(self, *keys: str) -> Self:
         """
         Return a new logger with *keys* removed from the context.
 
@@ -170,7 +177,7 @@ class BoundLogger(BoundLoggerBase):
         """
         return super().unbind(*keys)
 
-    def try_unbind(self, *keys: str) -> BoundLogger:
+    def try_unbind(self, *keys: str) -> Self:
         """
         Like :meth:`unbind`, but best effort: missing keys are ignored.
 
@@ -178,13 +185,13 @@ class BoundLogger(BoundLoggerBase):
         """
         return super().try_unbind(*keys)
 
-    def new(self, **new_values: Any) -> BoundLogger:
+    def new(self, **new_values: Any) -> Self:
         """
         Clear context and binds *initial_values* using `bind`.
 
         Only necessary with dict implementations that keep global state like
         those wrapped by `structlog.threadlocal.wrap_dict` when threads
-        are re-used.
+        are reused.
         """
         return super().new(**new_values)
 
@@ -780,7 +787,12 @@ def filter_by_level(
     ...
     DropEvent
     """
-    if logger.isEnabledFor(NAME_TO_LEVEL[method_name]):
+    if (
+        # We can't use logger.isEnabledFor() because it's always disabled when
+        # a log entry is in flight on Python 3.14 and later,
+        not logger.disabled
+        and NAME_TO_LEVEL[method_name] >= logger.getEffectiveLevel()
+    ):
         return event_dict
 
     raise DropEvent
@@ -1145,7 +1157,7 @@ class ProcessorFormatter(logging.Formatter):
             record.stack_info = None
 
         for p in self.processors:
-            ed = p(logger, meth_name, cast(EventDict, ed))
+            ed = p(logger, meth_name, ed)  # type: ignore[arg-type]
 
         if not isinstance(ed, str):
             warnings.warn(
