@@ -95,7 +95,7 @@ class TestConsoleRenderer:
         """
         cr = dev.ConsoleRenderer(colors=False, event_key="msg")
 
-        assert "new event name                 event=something custom" == cr(
+        assert "new event name                 event='something custom'" == cr(
             None, None, {"msg": "new event name", "event": "something custom"}
         )
 
@@ -545,10 +545,7 @@ class TestConsoleRenderer:
         r = dev.ConsoleRenderer(colors=False)
 
         assert (
-            "hi"
-            == r(
-                None, None, {"event": "hi", "exc_info": (None, None, None)}
-            ).rstrip()
+            "hi" == r(None, None, {"event": "hi", "exc_info": None}).rstrip()
         )
 
     def test_columns_warns_about_meaningless_arguments(self, recwarn):
@@ -614,6 +611,19 @@ class TestConsoleRenderer:
                 ]
             )
 
+    def test_does_not_modify_styles(self):
+        """
+        Instantiating ConsoleRenderer should not modify the styles passed in.
+
+        Ref #643
+        """
+        styles = {"info": "something"}
+        copy = styles.copy()
+
+        dev.ConsoleRenderer(level_styles=styles)
+
+        assert copy == styles
+
 
 class TestSetExcInfo:
     def test_wrong_name(self):
