@@ -13,6 +13,7 @@ import sys
 
 from io import StringIO
 from typing import Any, Callable, Collection, Dict
+from unittest.mock import patch
 
 import pytest
 import pytest_asyncio
@@ -24,6 +25,7 @@ from structlog import (
     ReturnLogger,
     configure,
     get_context,
+    wrap_logger,
 )
 from structlog._config import _CONFIG
 from structlog._log_levels import CRITICAL, NAME_TO_LEVEL, WARN
@@ -44,6 +46,7 @@ from structlog.stdlib import (
     filter_by_level,
     get_logger,
     recreate_defaults,
+    render_to_log_args_and_kwargs,
     render_to_log_kwargs,
 )
 from structlog.testing import CapturedCall
@@ -204,6 +207,15 @@ class TestBoundLogger:
 
         assert method_name == getattr(bl, method_name)("event")
 
+    def test_proxies_to_correct_method_special_cases(self):
+        """
+        Fatal maps to critical and warn to warning.
+        """
+        bl = BoundLogger(ReturnLogger(), [return_method_name], {})
+
+        assert "warning" == bl.warn("event")
+        assert "critical" == bl.fatal("event")
+
     def test_proxies_log(self):
         """
         BoundLogger.exception.log() is proxied to the appropriate method.
@@ -357,6 +369,20 @@ class TestBoundLogger:
             CapturedCall(method_name=meth, args=(), kwargs={"event": "Async!"})
         ] == cl.calls
 
+    async def test_async_log_methods_special_cases(self, cl):
+        """
+        afatal maps to critical.
+        """
+        bl = build_bl(cl, processors=[])
+
+        await bl.afatal("Async!")
+
+        assert [
+            CapturedCall(
+                method_name="critical", args=(), kwargs={"event": "Async!"}
+            )
+        ] == cl.calls
+
     async def test_alog(self, cl):
         """
         Alog logs async at the correct level.
@@ -637,7 +663,7 @@ class TestExtraAdder:
         handler.setLevel(0)
         logger.addHandler(handler)
         logger.setLevel(0)
-        logging.warning("allow = %s", allow)
+        logging.warning("allow = %s", allow)  # noqa: LOG015
 
         event_dict = {"event": "Some text"}
         expected = self._copy_allowed(event_dict, extra_dict, allow)
@@ -671,8 +697,182 @@ class TestExtraAdder:
         }
 
 
-class TestRenderToLogKW:
-    def test_default(self):
+@pytest.fixture(name="stdlib_logger")
+def _stdlib_logger():
+    logger = logging.getLogger("test_logger")
+    logger.setLevel(logging.DEBUG)
+
+    yield logger
+
+    logging.basicConfig()
+
+
+class TestRenderToLogArgsAndKwargs:
+    def test_default(self, stdlib_logger: logging.Logger):
+        """
+        Passes `event` key from `event_dict` in the first positional argument
+        and handles otherwise empty `event_dict`.
+        """
+        method_name = "debug"
+        event = "message"
+        args, kwargs = render_to_log_args_and_kwargs(
+            stdlib_logger, method_name, {"event": event}
+        )
+
+        assert (event,) == args
+        assert {} == kwargs
+
+        with patch.object(stdlib_logger, "_log") as mock_log:
+            getattr(stdlib_logger, method_name)(*args, **kwargs)
+
+        mock_log.assert_called_once_with(logging.DEBUG, event, ())
+
+    def test_pass_remaining_event_dict_as_extra(
+        self, stdlib_logger: logging.Logger, event_dict: dict[str, Any]
+    ):
+        """
+        Passes remaining `event_dict` as `extra`.
+        """
+        expected_extra = event_dict.copy()
+
+        method_name = "info"
+        event = "message"
+        event_dict["event"] = event
+
+        args, kwargs = render_to_log_args_and_kwargs(
+            stdlib_logger, method_name, event_dict
+        )
+
+        assert (event,) == args
+        assert {"extra": expected_extra} == kwargs
+
+        with patch.object(stdlib_logger, "_log") as mock_log:
+            getattr(stdlib_logger, method_name)(*args, **kwargs)
+
+        mock_log.assert_called_once_with(
+            logging.INFO, event, (), extra=expected_extra
+        )
+
+    def test_pass_positional_args_from_event_dict_as_args(
+        self, stdlib_logger: logging.Logger, event_dict: dict[str, Any]
+    ):
+        """
+        Passes items from "positional_args" key from `event_dict` as positional
+        arguments.
+        """
+        expected_extra = event_dict.copy()
+
+        method_name = "warning"
+        event = "message: a = %s, b = %d"
+        positional_args = ("foo", 123)
+        event_dict["event"] = event
+        event_dict["positional_args"] = positional_args
+
+        args, kwargs = render_to_log_args_and_kwargs(
+            stdlib_logger, method_name, event_dict
+        )
+
+        assert (event, *(positional_args)) == args
+        assert {"extra": expected_extra} == kwargs
+
+        with patch.object(stdlib_logger, "_log") as mock_log:
+            getattr(stdlib_logger, method_name)(*args, **kwargs)
+
+        mock_log.assert_called_once_with(
+            logging.WARNING, event, positional_args, extra=expected_extra
+        )
+
+    def test_pass_kwargs_from_event_dict_as_kwargs(
+        self, stdlib_logger: logging.Logger, event_dict: dict[str, Any]
+    ):
+        """
+        Passes "exc_info", "stack_info", and "stacklevel" keys from `event_dict`
+        as keyword arguments.
+        """
+        expected_extra = event_dict.copy()
+
+        method_name = "info"
+        event = "message"
+        exc_info = True
+        stack_info = False
+        stacklevel = 2
+        event_dict["event"] = event
+        event_dict["exc_info"] = exc_info
+        event_dict["stack_info"] = stack_info
+        event_dict["stacklevel"] = stacklevel
+
+        args, kwargs = render_to_log_args_and_kwargs(
+            stdlib_logger, method_name, event_dict
+        )
+
+        assert (event,) == args
+        assert {
+            "exc_info": exc_info,
+            "stack_info": stack_info,
+            "stacklevel": stacklevel,
+            "extra": expected_extra,
+        } == kwargs
+
+        with patch.object(stdlib_logger, "_log") as mock_log:
+            getattr(stdlib_logger, method_name)(*args, **kwargs)
+
+        mock_log.assert_called_once_with(
+            logging.INFO,
+            event,
+            (),
+            exc_info=exc_info,
+            stack_info=stack_info,
+            stacklevel=stacklevel,
+            extra=expected_extra,
+        )
+
+    def test_integration(
+        self, stdlib_logger: logging.Logger, event_dict: dict[str, Any]
+    ):
+        """
+        `render_to_log_args_and_kwargs` with a wrapped logger calls the stdlib
+        logger correctly.
+
+        Reserved stdlib keyword arguments are in `logging.Logger._log`.
+        https://github.com/python/cpython/blob/60403a5409ff2c3f3b07dd2ca91a7a3e096839c7/Lib/logging/__init__.py#L1640
+        """
+        event = "message: a = %s, b = %d"
+        arg_1 = "foo"
+        arg_2 = 123
+        exc_info = False
+        stack_info = True
+        stacklevel = 3
+
+        struct_logger = wrap_logger(
+            stdlib_logger,
+            processors=[render_to_log_args_and_kwargs],
+            wrapper_class=BoundLogger,
+        )
+
+        with patch.object(stdlib_logger, "_log") as mock_log:
+            struct_logger.info(
+                event,
+                arg_1,
+                arg_2,
+                exc_info=exc_info,
+                stack_info=stack_info,
+                stacklevel=stacklevel,
+                **event_dict,
+            )
+
+        mock_log.assert_called_once_with(
+            logging.INFO,
+            event,
+            (arg_1, arg_2),
+            exc_info=exc_info,
+            stack_info=stack_info,
+            stacklevel=stacklevel,
+            extra=event_dict,
+        )
+
+
+class TestRenderToLogKwargs:
+    def test_default(self, stdlib_logger):
         """
         Translates `event` to `msg` and handles otherwise empty `event_dict`s.
         """
@@ -680,7 +880,13 @@ class TestRenderToLogKW:
 
         assert {"msg": "message", "extra": {}} == d
 
-    def test_add_extra_event_dict(self, event_dict):
+        # now check stdlib logger likes those kwargs
+        with patch.object(stdlib_logger, "_log") as mock_log:
+            stdlib_logger.info(**d)
+
+        mock_log.assert_called_once_with(logging.INFO, "message", (), extra={})
+
+    def test_add_extra_event_dict(self, event_dict, stdlib_logger):
         """
         Adds all remaining data from `event_dict` into `extra`.
         """
@@ -689,9 +895,17 @@ class TestRenderToLogKW:
 
         assert {"msg": "message", "extra": event_dict} == d
 
-    def test_handles_special_kw(self, event_dict):
+        # now check stdlib logger likes those kwargs
+        with patch.object(stdlib_logger, "_log") as mock_log:
+            stdlib_logger.info(**d)
+
+        mock_log.assert_called_once_with(
+            logging.INFO, "message", (), extra=event_dict
+        )
+
+    def test_handles_special_kw(self, event_dict, stdlib_logger):
         """
-        "exc_info", "stack_info", and "stackLevel" aren't passed as extras.
+        "exc_info", "stack_info", and "stacklevel" aren't passed as extras.
 
         Cf. https://github.com/hynek/structlog/issues/424
         """
@@ -700,22 +914,68 @@ class TestRenderToLogKW:
 
         event_dict["exc_info"] = True
         event_dict["stack_info"] = False
-        event_dict["stackLevel"] = 1
+        event_dict["stacklevel"] = 1
+        event_dict["stackLevel"] = 1  # not a reserved kw
 
         d = render_to_log_kwargs(None, None, event_dict)
-
-        assert {
+        expected = {
             "msg": "message",
             "exc_info": True,
             "stack_info": False,
-            "stackLevel": 1,
+            "stacklevel": 1,
             "extra": {
                 "b": [3, 4],
                 "x": 7,
                 "y": "test",
                 "z": (1, 2),
+                "stackLevel": 1,
             },
-        } == d
+        }
+
+        assert expected == d
+
+        # now check stdlib logger likes those kwargs
+        with patch.object(stdlib_logger, "_log") as mock_log:
+            stdlib_logger.info(**d)
+
+        expected.pop("msg")
+        mock_log.assert_called_once_with(
+            logging.INFO, "message", (), **expected
+        )
+
+    def test_integration_special_kw(self, event_dict, stdlib_logger):
+        """
+        render_to_log_kwargs with a wrapped logger calls the stdlib logger
+        correctly
+
+        reserved stdlib keywords are in logging.Logger._log
+        https://github.com/python/cpython/blob/ae7b17673f29efe17b416cbcfbf43b5b3ff5977c/Lib/logging/__init__.py#L1632
+        """
+        expected = {
+            "msg": "message",
+            "exc_info": True,
+            "stack_info": False,
+            "stacklevel": 1,
+            "extra": {**event_dict},
+        }
+
+        event_dict["exc_info"] = True
+        event_dict["stack_info"] = False
+        event_dict["stacklevel"] = 1
+
+        struct_logger = wrap_logger(
+            stdlib_logger,
+            processors=[render_to_log_kwargs],
+        )
+
+        # now check struct logger passes those kwargs to stdlib
+        with patch.object(stdlib_logger, "_log") as mock_log:
+            struct_logger.info("message", **event_dict)
+
+        expected.pop("msg")
+        mock_log.assert_called_once_with(
+            logging.INFO, "message", (), **expected
+        )
 
 
 @pytest.fixture(name="configure_for_processor_formatter")
@@ -1237,14 +1497,14 @@ class TestAsyncBoundLogger:
             CapturedCall(method_name="info", args=(), kwargs={"event": "test"})
         ] == cl.calls
 
-    @pytest.mark.asyncio()
+    @pytest.mark.asyncio
     async def test_protocol(self, abl):
         """
         AsyncBoundLogger is a proper BindableLogger.
         """
         assert isinstance(abl, BindableLogger)
 
-    @pytest.mark.asyncio()
+    @pytest.mark.asyncio
     async def test_correct_levels(self, abl, cl, stdlib_log_method):
         """
         The proxy methods call the correct upstream methods.
@@ -1253,12 +1513,20 @@ class TestAsyncBoundLogger:
 
         aliases = {"warn": "warning"}
 
-        alias = aliases.get(stdlib_log_method)
-        expect = alias if alias else stdlib_log_method
+        expect = aliases.get(stdlib_log_method, stdlib_log_method)
 
         assert expect == cl.calls[0].method_name
 
-    @pytest.mark.asyncio()
+    @pytest.mark.asyncio
+    async def test_correct_level_fatal(self, abl, cl):
+        """
+        fatal, that I have no idea why we support, maps to critical.
+        """
+        await abl.bind(foo="bar").fatal("42")
+
+        assert "critical" == cl.calls[0].method_name
+
+    @pytest.mark.asyncio
     async def test_log_method(self, abl, cl):
         """
         The `log` method is proxied too.
@@ -1267,7 +1535,7 @@ class TestAsyncBoundLogger:
 
         assert "error" == cl.calls[0].method_name
 
-    @pytest.mark.asyncio()
+    @pytest.mark.asyncio
     async def test_exception(self, abl, cl):
         """
         `exception` makes sure 'exc_info" is set, if it's not set already.
@@ -1282,7 +1550,7 @@ class TestAsyncBoundLogger:
         assert ValueError is ei[0]
         assert ("omg",) == ei[1].args
 
-    @pytest.mark.asyncio()
+    @pytest.mark.asyncio
     async def test_exception_do_not_overwrite(self, abl, cl):
         """
         `exception` leaves exc_info be, if it's set.
@@ -1299,7 +1567,7 @@ class TestAsyncBoundLogger:
         ei = cl.calls[0].kwargs["exc_info"]
         assert (o1, o2, o3) == ei
 
-    @pytest.mark.asyncio()
+    @pytest.mark.asyncio
     async def test_bind_unbind(self, cl):
         """
         new/bind/unbind/try_unbind are correctly propagated.
@@ -1330,7 +1598,7 @@ class TestAsyncBoundLogger:
         assert {} == l5._context
         assert l4 is not l5
 
-    @pytest.mark.asyncio()
+    @pytest.mark.asyncio
     async def test_integration(self, capsys):
         """
         Configure and log an actual entry.
